.. _mayavi-examples-index:

Mayavi Gallery
==============

.. warning:: Mayavi scraping is deprecated and will be removed in 0.13.0. See
             :ref:`mayavi_scraper` for how to continue using Mayavi scraping
             if it's part of your sphinx-gallery builds.

.. _general_mayavi_examples:

Mayavi examples
---------------

Examples from the Sphinx-Gallery using Mayavi for embedding 3d plots.
